Learn R Programming

FrechForest (version 0.8.1)

OOB.rfshape: OOB error for a Frechet random forest

Description

Computes the OOB error of a given Frechet random forest

Usage

OOB.rfshape(rf, X, Y, time, id, timeScale = 0.1)

Arguments

rf

: Frechet random forest

X

[matrix]: matrix of the explanatory variables used to build the tree

Y

[vector]: output curves used to build the tree

time

[vector]: time measurements

id

[vector]: IDs of measurements

timeScale

[numeric]: allow to modify the time scale, increasing or decreasing the cost of the horizontal shift. If timeScale is very big, then the Frechet mean tends to the Euclidean distance. If timeScale is very small, then it tends to the Dynamic Time Warping.