Learn R Programming

FrechForest (version 0.8.1)

OOB.tree: OOB.tree

Description

Computes the oob error of a given tree:

Usage

OOB.tree(tree, X, Y, id, time, timeScale = 0.1)

Arguments

tree

: Frechet tree

X

[matrix]: matrix of the explanatory variables used to build the tree

Y

[vector]: output curves used to build the tree

id

[vector]: IDs of measurements

time

[vector]: time measurements

timeScale

[numeric]: allow to modify the time scale, increasing or decreasing the cost of the horizontal shift. If timeScale is very big, then the Frechet mean tends to the Euclidean distance. If timeScale is very small, then it tends to the Dynamic Time Warping.