Learn R Programming

FrechForest (version 0.8.1)

Rtmax: Maximal randomized Fr<U+00E9>chet tree

Description

Build a maximal randomized Fr<U+00E9>chet tree

Usage

Rtmax(X, Y, id, time, mtry, timeScale = 0.1, ...)

Arguments

X

[matrix]: Matrix of explanatory variables, each column codes for a variable

Y

[vector]: Output curves

id

[vector]: IDs of measurements

time

[vector]: time measurements

mtry

[numeric]: number of variables randomly chosen at each split

timeScale

[numeric]: allow to modify the time scale, increasing or decreasing the cost of the horizontal shift. If timeScale is very big, then the Frechet mean tends to the Euclidean distance. If timeScale is very small, then it tends to the Dynamic Time Warping.

...

: