Learn R Programming

FrechForest (version 0.8.1)

Tmax: Maximal Frechet tree

Description

builds the maximal Frechet tree

Usage

Tmax(X, Y, id, time, timeScale = 0.1, ...)

Arguments

X

[matrix]: Matrix of explanatory variables, each column codes for a variable

Y

[vector]: Output curves

id

[vector]: IDs of trajectories

time

[vector]: Time at which measures are made

timeScale

[numeric]: allow to modify the time scale, increasing or decreasing the cost of the horizontal shift. If timeScale is very big, then the Frechet mean tends to the Euclidean distance. If timeScale is very small, then it tends to the Dynamic Time Warping.

...

: