Learn R Programming

FrechForest (version 0.8.1)

TreeShapeCV: Cross validated Frechet tree

Description

Builds a Frechet tree that is selected with cross validation

Usage

TreeShapeCV(X, Y, id, time, ...)

Arguments

X

[matrix]: a data frame or a matrix of trajectories predictors. Each colunm codes for a trajectory predictor.

Y

[vector]: a vector containing the output trajectories (same length as nrow(X)).

id

[vector (factor)]: identifier, one for each trajectory to attribute each measurement of X and Y to one of the trajectories (same length as Y).

time

[vector]: time measurements for the observations of both X and Y (same length as Y).

...

: optional parameters to be passed to the low level function