Learn R Programming

FrechForest (version 0.8.1)

impurity: Impurity

Description

Computes the Frechet Variance from a group of curves

Usage

impurity(traj, time, id, timeScale = 0.1)

Arguments

traj

[vector]: Vector of curves

time

[vector]: Time measurements of the different curves (same length as traj)

id

[vector]: IDs of the different measurements (same length as traj)

timeScale

[numeric]: allow to modify the time scale, increasing or decreasing the cost of the horizontal shift. If timeScale is very big, then the Frechet mean tends to the Euclidean distance. If timeScale is very small, then it tends to the Dynamic Time Warping.