Learn R Programming

FrechForest (version 0.8.1)

impurity_split: Split Impurity

Description

Computes the Frechet variance reduction from a split

Usage

impurity_split(traj, time, id, split, timeScale = 0.1)

Arguments

traj

[vector]: Trajectories

time

[vector]: Times at which measures are made

id

[vector]: IDs of the different measurements

split

[numeric]: Variable of split

timeScale

[numeric]: allow to modify the time scale, increasing or decreasing the cost of the horizontal shift. If timeScale is very big, then the Frechet mean tends to the Euclidean distance. If timeScale is very small, then it tends to the Dynamic Time Warping.