Learn R Programming

FrechForest (version 0.8.1)

ordonne: Ordonne time measurements

Description

Used to put the data to the right form at a given time

Usage

ordonne(X, time, id)

Arguments

X

[vector]: matrix of covariables, each variable must be in column

time

[vector]: time measurements of the observations

id

[vector]: IDs of the measurements to their belonging curves