Learn R Programming

FrechForest (version 0.8.1)

rf_shape: Frechet random forest

Description

Build a Frechet random Forest

Usage

rf_shape(X, Y, id, time, mtry, ntree, timeScale = 0.1, ERtrees = FALSE,
  ...)

Arguments

X

[matrix]: Matrix of explanatory variables, each column codes for a variable

Y

[vector]: Output curves

id

[vector]: IDs of measurements

time

[vector]: time of measurements

mtry

[numeric]: number of variables randomly chosen at each split

ntree

[numeric]: number of randomized Frechet trees composing the Frechet random forest

timeScale

[numeric]: allow to modify the time scale, increasing or decreasing the cost of the horizontal shift. If timeScale is very big, then the Frechet mean tends to the Euclidean distance. If timeScale is very small, then it tends to the Dynamic Time Warping.

...

: