Learn R Programming

FrechForest (version 0.8.1)

rf_shape_para: Parallelized Frechet random forest

Description

A parallelized version of "rf_Shape" function

Usage

rf_shape_para(X, Y, id, time, mtry, ntree, ncores, timeScale = 0.1,
  ERT = FALSE, ...)

Arguments

X

[matrix]: Matrix of explanatory variables, each column codes for a variable

Y

[vector]: Output curves

id

[vector]: IDs of measurements

time

[vector]: time of measurements

mtry

[numeric]: number of variables randomly chosen at each split

ntree

[numeric]: number of randomized Frechet trees composing the Frechet random forest

ncores

[numeric]: number of cores used in parallel

timeScale

[numeric]: allow to modify the time scale, increasing or decreasing the cost of the horizontal shift. If timeScale is very big, then the Frechet mean tends to the Euclidean distance. If timeScale is very small, then it tends to the Dynamic Time Warping.

ERT

[boolean]: if TRUE uses Extremly randomized Frechet trees to build the Frechet forest

...

: