Learn R Programming

FrechForest (version 0.8.1)

var_split: Variable split

Description

Determines the split from a set of input and output variables which are curves:

Usage

var_split(X, Y, time, id, timeScale = 0.1, ...)

Arguments

X

[matrix]: Matrix of explanatory variables, each column codes for a variable.

Y

[vector]: Output curves

time

[vector]: Time at which measures are made

id

[vector]: IDs of trajectories

timeScale

[numeric]: allow to modify the time scale, increasing or decreasing the cost of the horizontal shift. If timeScale is very big, then the Frechet mean tends to the euclidiean distance. If timeScale is very small, then it tends to the Dynamic Time Warping.

...

: