Computes the oob error of a given tree:
OOB.tree(tree, X, Y, id, time, timeScale = 0.1): Frechet tree
[matrix]: matrix of the explanatory variables used to build the tree
[vector]: output curves used to build the tree
[vector]: IDs of measurements
[vector]: time measurements
[numeric]: allow to modify the time scale, increasing or decreasing the cost of the horizontal shift. If timeScale is very big, then the Frechet mean tends to the Euclidean distance. If timeScale is very small, then it tends to the Dynamic Time Warping.