Build a maximal randomized Fr<U+00E9>chet tree
Rtmax(X, Y, id, time, mtry, timeScale = 0.1, ...)[matrix]: Matrix of explanatory variables, each column codes for a variable
[vector]: Output curves
[vector]: IDs of measurements
[vector]: time measurements
[numeric]: number of variables randomly chosen at each split
[numeric]: allow to modify the time scale, increasing or decreasing the cost of the horizontal shift. If timeScale is very big, then the Frechet mean tends to the Euclidean distance. If timeScale is very small, then it tends to the Dynamic Time Warping.
: