builds the maximal Frechet tree
Tmax(X, Y, id, time, timeScale = 0.1, ...)[matrix]: Matrix of explanatory variables, each column codes for a variable
[vector]: Output curves
[vector]: IDs of trajectories
[vector]: Time at which measures are made
[numeric]: allow to modify the time scale, increasing or decreasing the cost of the horizontal shift. If timeScale is very big, then the Frechet mean tends to the Euclidean distance. If timeScale is very small, then it tends to the Dynamic Time Warping.
: