predict.Frechforest: Frechet random forests prediction function
Description
Given a Frechet tree and new input trajectories predictors X, this function allows to predict output trajectories Y associated with the new X given a Frechet random forest
Usage
# S3 method for Frechforest
predict(object, X, time, id, timeScale = 0.1, ...)
Arguments
object
[list]: a list of the randomized Frechet tree composing the Frechet random forest.
X
[matrix]: a data frame or a matrix of trajectories predictors.
time
[vector]: time measurements of the new trajectories to predict.
id
[vector]: identifier, one for each trajectory to attribute each measurement of X to one of the trajectories.
timeScale
[numeric]: allow to modify the time scale, increasing or decreasing the cost of the horizontal shift. If timeScale is very big, then the Frechet mean tends to the Euclidean distance. If timeScale is very small, then it tends to the Dynamic Time Warping.
...
: optional parameters to be passed to the low level function.