A parallelized version of "rf_Shape" function
rf_shape_para(X, Y, id, time, mtry, ntree, ncores, timeScale = 0.1,
ERT = FALSE, ...)[matrix]: Matrix of explanatory variables, each column codes for a variable
[vector]: Output curves
[vector]: IDs of measurements
[vector]: time of measurements
[numeric]: number of variables randomly chosen at each split
[numeric]: number of randomized Frechet trees composing the Frechet random forest
[numeric]: number of cores used in parallel
[numeric]: allow to modify the time scale, increasing or decreasing the cost of the horizontal shift. If timeScale is very big, then the Frechet mean tends to the Euclidean distance. If timeScale is very small, then it tends to the Dynamic Time Warping.
[boolean]: if TRUE uses Extremly randomized Frechet trees to build the Frechet forest
: