Determines the split from a set of input and output variables which are curves:
var_split(X, Y, time, id, timeScale = 0.1, ...)[matrix]: Matrix of explanatory variables, each column codes for a variable.
[vector]: Output curves
[vector]: Time at which measures are made
[vector]: IDs of trajectories
[numeric]: allow to modify the time scale, increasing or decreasing the cost of the horizontal shift. If timeScale is very big, then the Frechet mean tends to the euclidiean distance. If timeScale is very small, then it tends to the Dynamic Time Warping.
: